==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/content/logistics/item/filter/attribute/SingletonItemAttribute.java <==
package com.zurrtum.create.content.logistics.item.filter.attribute;

import com.mojang.serialization.Codec;
import com.mojang.serialization.MapCodec;
import org.jetbrains.annotations.NotNull;

import java.util.List;
import java.util.function.BiPredicate;
import java.util.function.Function;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_9129;
import net.minecraft.class_9139;

public final class SingletonItemAttribute implements ItemAttribute {
    private final Type type;
    private final BiPredicate<class_1799, class_1937> predicate;
    private final String translationKey;

    public SingletonItemAttribute(Type type, BiPredicate<class_1799, class_1937> predicate, String translationKey) {
        this.type = type;
        this.predicate = predicate;
        this.translationKey = translationKey;
    }

    @Override
    public boolean appliesTo(class_1799 stack, class_1937 world) {
        return predicate.test(stack, world);
    }

    @Override
    public ItemAttributeType getType() {
        return type;
    }

    @Override
    public String getTranslationKey() {
        return translationKey;
    }

    public static final class Type implements ItemAttributeType {
        private final SingletonItemAttribute attribute;

        public Type(Function<Type, SingletonItemAttribute> singletonFunc) {
            this.attribute = singletonFunc.apply(this);
        }

        @Override
        public @NotNull ItemAttribute createAttribute() {
            return attribute;
        }

        @Override
        public List<ItemAttribute> getAllAttributes(class_1799 stack, class_1937 level) {
            if (attribute.appliesTo(stack, level)) {
                return List.of(attribute);
            }
            return List.of();
        }

        @Override
        public MapCodec<? extends ItemAttribute> codec() {
            return Codec.unit(attribute).fieldOf("value");
        }

        @Override
        public class_9139<? super class_9129, ? extends ItemAttribute> packetCodec() {
            return class_9139.method_56431(attribute);
        }
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/content/logistics/item/filter/attribute/SingletonItemAttribute.java <==
package com.zurrtum.create.content.logistics.item.filter.attribute;

import com.mojang.serialization.MapCodec;
import org.jetbrains.annotations.NotNull;

import java.util.List;
import java.util.function.BiPredicate;
import java.util.function.Function;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_9129;
import net.minecraft.class_9139;

public final class SingletonItemAttribute implements ItemAttribute {
    private final Type type;
    private final BiPredicate<class_1799, class_1937> predicate;
    private final String translationKey;

    public SingletonItemAttribute(Type type, BiPredicate<class_1799, class_1937> predicate, String translationKey) {
        this.type = type;
        this.predicate = predicate;
        this.translationKey = translationKey;
    }

    @Override
    public boolean appliesTo(class_1799 stack, class_1937 world) {
        return predicate.test(stack, world);
    }

    @Override
    public ItemAttributeType getType() {
        return type;
    }

    @Override
    public String getTranslationKey() {
        return translationKey;
    }

    public static final class Type implements ItemAttributeType {
        private final SingletonItemAttribute attribute;

        public Type(Function<Type, SingletonItemAttribute> singletonFunc) {
            this.attribute = singletonFunc.apply(this);
        }

        @Override
        public @NotNull ItemAttribute createAttribute() {
            return attribute;
        }

        @Override
        public List<ItemAttribute> getAllAttributes(class_1799 stack, class_1937 level) {
            if (attribute.appliesTo(stack, level)) {
                return List.of(attribute);
            }
            return List.of();
        }

        @Override
        public MapCodec<? extends ItemAttribute> codec() {
            return MapCodec.unitCodec(attribute).fieldOf("value");
        }

        @Override
        public class_9139<? super class_9129, ? extends ItemAttribute> packetCodec() {
            return class_9139.method_56431(attribute);
        }
    }
}
